* ************************************************************************* *
* Copyright @ 2000 Douglas Cochrane & Associates LLC (DC&A), Eugene, Oregon *
* ************************************************************************* *
* Copyright @ 2006 Douglas Cochrane & Associates LLC (DC&A), Eugene, Oregon *
*                                                                           *
* 2006 Update by Davis G. Parsons II (davisp2@earthlink.net)                *
*****************************************************************************
*                                                                           *
*                                                                           *
* 2009 Update by Davis G. Parsons II (davisp2@att.net)                      *
*****************************************************************************
*                                                                           *
*                                                                           *
* 2010 Update by Davis G. Parsons II (davisp2@att.net)                      *
*****************************************************************************
*                                                                           *
*                                                                           *
* 2011 Update by Davis G. Parsons II (davisp2@att.net)                      *
*****************************************************************************

* Aisc_Search is a search function for retrieving data from 
* the AISC table regarding properties of steel shapes and sizes.
* Aisc_Search was written and compiled using Microsoft FoxPro V6.
	****>2006 update to Foxpro V9.0 SP1<****
	****>2009 update to Foxpro V9.0 SP2<****
	****>2010 update to Foxpro V9.0 SP2<****
	****>2011 update to Foxpro V9.0 SP2<****
* It incorporates the AISC Excel table titled "DB-US units v2.2.XLS"
	****>2006 update to AISC.Shapes.Database.v13.0.xls<****
	****>2009 update to AISC_v13_1_1.xls<****
	****>2010 update to AISC_v13_2.xls<****
	****>2011 update to AISC_V14_0_0.xls<****
* which has been converted from .XLS to .DBF format
* and compiled into this program using the filename "AISC_Imperial.DBF"
	****>2006 update to AISC_v13.DBF<****
	****>2009 update to AISC_v13_1_1.DBF<****
	****>2010 update to AISC_v13_2.DBF<****
	****>2011 update to AISC_V14_0_0.DBF<****

* NOTE that if the AISC changes the format of their tables, the long IF statement
* in the code below may need to be updated to reflect any new or changed field names.

* This program was created by Douglas Cochrane, founder of FabTrol Systems, Inc.
* for the benefit of the American Institute of Steel Construction (AISC)
* and the steel fabrication industry in general.

* It has been placed in the public domain by DC&A with the following stipulations:
*   1) DC&A make no commitments regarding the usability of this product 
*      or the accuracy of the data provided by the AISC.
*   2) Software developers may use and distribute this product royalty free
*      contingent upon paying any royalties required by the AISC for use
*      of their data tables.
*   3) Software developers may modify this product as necessary 
*      but are requested to send a copy of the modifications to 
*      the author at cochrane@fabtrol.com. Modifications may be 
*      incorporated into the public domain product for the benefit
*      of all users.

* The program is provided as
*    AISC_Search.DLL, a fully functional self contained callable module that may be 
*    compiled into other software products. AISC_Search.DLL is completely self-contained 
*    and requires Foxpro V9.0 runtime files to be installed in the System32 folder.
*    A VBA file is required to give calling procedures for Excel.

* Calling parameters include:
*    1)  Shape and Size, such as W6x15 or L2x2x1/4
*        using the AISC Standardized Nomenclature. This parameter is not case sensitive.
*        Extraneous spaces are removed.
*    2)  The property value desired, such as Area (A) or Web Thickness (TW). This 
*        parameter is not case sensitive. For more information, see the list of acceptable 
*        values listed in the long IF statement in the code below

* The value returned is the value listed in the AISC tables. This data is provided by 
* the AISC which is solely responsible for its accuracy.

* If the value cannot be found, due to erroneous inputs or incomplete data
* in the AISC tables, the return value will be zero (0)

* 14 June 01 [mjarvis@fabtrol.com] add fields Kdet and KDes for new AISC structure. 
*             Left field "K" in there n case someone calls old data with the new program

DEFINE CLASS AISC_Field_Value AS CUSTOM OLEPUBLIC

PROCEDURE AISC_Field_Value_Function

LPARAMETERS cThisSize, cThisValue

* Set up the environment to operate quietly and with utmost exactitude
SET TALK OFF
SET EXACT ON

* nReturnValue is the value returned from the table. If not found, it returns zero
nReturnValue = -1

* lSizeOk is a logical that determines whether the Size passed in is valid
* If cThisSize is a character string and is found in the list titled EDI_Std, lSizeOk = .T.
lSizeOk      = .F.

* lValueOk is a logical that determines whether the Value passed in is valid
* If cThisValue is a character string and is a valid field name (in the long IF statement below), 
* then lValueOk becomes .T.
lValueOk     = .F.

* Make sure cThisSize is a character string
IF TYPE( 'cThisSize' ) = 'C'
  lSizeOk    = .T.
  * Convert the string to Caps and remove extraneous spaces
  cThisSize  = UPPER( STRTRAN( cThisSize, ' ', '' ))
ENDIF

* Make sure cThisValue is a character string 
IF TYPE( 'cThisValue' ) = 'C'
  lValueOk   = .T.
  * Convert the string to Caps
  cThisValue = UPPER( cThisValue )
ENDIF

IF lSizeOk AND lValueOk 
  * Make sure that the field name passed in is a valid choice
  * If the fields are changed by the AISC in the future, add to or edit this list
  IF cThisValue = 'METRIC'     OR ;   && added 2011
     cThisValue = 'TYPE'       OR ;
     cThisValue = 'EDI_STD'    OR ;   && revised name-2006
     cThisValue = 'AISC_MAN'   OR ;   && revised name-2006
     cThisValue = 'T_F'        OR ;
     cThisValue = 'W'          OR ;
     cThisValue = 'A'          OR ;
     cThisValue = 'D'          OR ;
     cthisValue = 'DDET'       OR ;   && added 2009
     cThisValue = 'HT'         OR ;
     cThisValue = 'OD'         OR ;
     cThisValue = 'BF'         OR ;
     cThisvalue = 'BFDET'      OR ;   && added 2009
     cThisValue = 'B'          OR ;
     cThisValue = 'ID'         OR ;
     cThisValue = 'TW'         OR ;
     cthisValue = 'TWDET'      OR ;   && added 2009
     cthisValue = 'TWDET_2'    OR ;   && added 2009
     cThisValue = 'TF'         OR ;
     cthisValue = 'TFDET'      OR ;   && added 2009
     cThisValue = 'T'          OR ;
     cThisValue = 'TNOM'       OR ;
     cThisValue = 'TDES'       OR ;
     cThisValue = 'KDES'       OR ;  
     cThisValue = 'KDET'       OR ;
     cThisValue = 'K1'         OR ;   && took out "K", added "K1"-2006
     cThisValue = 'X'          OR ;
     cThisValue = 'Y'          OR ;
     cThisValue = 'EO'         OR ;
     cThisValue = 'XP'         OR ;
     cThisValue = 'YP'         OR ;
     cThisValue = 'BF_2TF'     OR ;
     cThisValue = 'B_T'        OR ;
     cThisValue = 'H_TW'       OR ;
     cThisValue = 'H_T'        OR ;
     cThisValue = 'D_T'        OR ;   && Deleted "FY3P","X1","X2",LX"-2006
     cThisValue = 'IX'         OR ;   && Added IX-2006
     cThisValue = 'ZX'         OR ;
     cThisValue = 'SX'         OR ;
     cThisValue = 'RX'         OR ;
     cThisvalue = 'IY'         OR ;   && Deleted "LY",added "IY"-2006
     cThisValue = 'ZY'         OR ;
     cThisValue = 'SY'         OR ;
     cThisValue = 'RY'         OR ;
     cThisValue = 'IZ'         OR ;   && added 2011
     cThisValue = 'RZ'         OR ;
     cthisValue = 'SZ'         OR ;   && added 2009
     cThisValue = 'J'          OR ;
     cThisValue = 'CW'         OR ;
     cThisValue = 'C'          OR ;
     cThisValue = 'WNO'        OR ;
     cThisValue = 'SW1'        OR ;   && Changed to SW1 2011
     cThisValue = 'SW2'        OR ;   && added 2011
     cThisValue = 'SW3'        OR ;   && added 2011
     cThisValue = 'QF'         OR ;
     cThisValue = 'QW'         OR ;
     cThisValue = 'RO'         OR ;
     cThisValue = 'H'          OR ;
     cThisValue = 'TAN_ALPHA'  OR ;
     cThisvalue = 'QS'         OR ;   && added 2011
     cThisvalue = 'IW'         OR ;   && added 2011
     cThisvalue = 'SWA'        OR ;   && added 2011
     cThisvalue = 'SWB'        OR ;   && added 2011
     cThisvalue = 'SWC'        OR ;   && added 2011
     cThisvalue = 'SZA'        OR ;   && added 2011
     cThisvalue = 'SZB'        OR ;   && added 2011
     cThisvalue = 'SZC'        OR ;   && added 2011
     cThisvalue = 'RTS'        OR ;   && added 2011
     cThisvalue = 'HO'         OR ;   && added 2011
     cThisvalue = 'PA'         OR ;   && added 2011 - next line also
     cThisvalue = 'PB'

     lValueOk = .T.
  ELSE
     lValueOk = .F.
  ENDIF

  * This is where we do the actual look up
  IF lSizeOk AND lValueOk

    * Make sure our file is in use and the index is set correctly
    IF NOT USED( 'AISC1' )
      USE AISC_V14_0_0 IN 0 ALIAS AISC1
    ENDIF

    SELECT AISC1
    SET ORDER TO EDI_STD
    
    * Find the correct record
    IF SEEK( cThisSize )
      * Find the value in the specified field
      nReturnValue = &cThisValue
    ENDIF

	* Check if 0 value in table, if so return a dash
    IF TYPE( 'nReturnValue' ) = 'N' AND nReturnvalue = 0 && 2011
       nReturnValue = '-'								 && 2011
    ELSE												 && 2011
       nReturnValue = &cThisValue						 && 2011
    ENDIF												 && 2011

  ENDIF lSizeOk AND lValueOk AND Aisc_Lookup()
ENDIF lSizeOk AND lValueOk

RETURN nReturnValue

ENDPROC

ENDDEFINE

* ************************************************************************* *
* Copyright @ 2000 Douglas Cochrane & Associates LLC (DC&A), Eugene, Oregon *
* ************************************************************************* *
* Copyright @ 2006 Douglas Cochrane & Associates LLC (DC&A), Eugene, Oregon *
*                                                                           *
* 2006 Update by Davis G. Parsons II (davisp2@earthlink.net)                *
*****************************************************************************
*                                                                           *
*                                                                           *
* 2009 Update by Davis G. Parsons II (davisp2@att.net)                      *
*****************************************************************************
*                                                                           *
*                                                                           *
* 2010 Update by Davis G. Parsons II (davisp2@att.net)                      *
*****************************************************************************
*                                                                           *
*                                                                           *
* 2011 Update by Davis G. Parsons II (davisp2@att.net)                      *
*****************************************************************************
